searchData={"items":[{"type":"module","title":"TelemetryMetricsPrometheus.Core","doc":"Prometheus Reporter for [`Telemetry.Metrics`](https://github.com/beam-telemetry/telemetry_metrics) definitions.\n\nProvide a list of metric definitions to the `child_spec/1` function. It's recommended to\nadd this to your supervision tree.\n\n    def start(_type, _args) do\n      # List all child processes to be supervised\n      children = [\n        {TelemetryMetricsPrometheus.Core, [\n          metrics: [\n            counter(\"http.request.count\"),\n            sum(\"http.request.payload_size\", unit: :byte),\n            sum(\"websocket.connection.count\", reporter_options: [prometheus_type: :gauge]),\n            last_value(\"vm.memory.total\", unit: :byte)\n          ]\n        ]}\n      ]\n\n      opts = [strategy: :one_for_one, name: ExampleApp.Supervisor]\n      Supervisor.start_link(children, opts)\n    end\n\nNote that aggregations for distributions (histogram) only occur at scrape time.\nThese aggregations only have to process events that have occurred since the last\nscrape, so it's recommended at this time to keep an eye on scrape durations if\nyou're reporting a large number of distributions or you have a high tag cardinality.","ref":"TelemetryMetricsPrometheus.Core.html"},{"type":"module","title":"Telemetry.Metrics to Prometheus Equivalents - TelemetryMetricsPrometheus.Core","doc":"Metric types:\n  * Counter - Counter\n  * Distribution - Histogram\n  * LastValue - Gauge\n  * Sum - Counter/Gauge\n  * Summary - Summary (Not supported)\n\n#","ref":"TelemetryMetricsPrometheus.Core.html#module-telemetry-metrics-to-prometheus-equivalents"},{"type":"module","title":"Units - TelemetryMetricsPrometheus.Core","doc":"Prometheus recommends the usage of base units for compatibility - [Base Units](https://prometheus.io/docs/practices/naming/#base-units).\nThis is simple to do with `:telemetry` and `Telemetry.Metrics` as all memory\nrelated measurements in the BEAM are reported in bytes and Metrics provides\nautomatic time unit conversions.\n\nNote that measurement unit should used as part of the reported name in the case of\nhistograms and gauges to Prometheus. As such, it is important to explicitly define\nthe unit of measure for these types when the unit is time or memory related.\n\nIt is suggested to not mix units, e.g. seconds with milliseconds.\n\nIt is required to define your buckets according to the end unit translation\nsince this measurements are converted at the time of handling the event, prior\nto bucketing.\n\n##","ref":"TelemetryMetricsPrometheus.Core.html#module-units"},{"type":"module","title":"Memory - TelemetryMetricsPrometheus.Core","doc":"Report memory as `:byte`.\n\n##","ref":"TelemetryMetricsPrometheus.Core.html#module-memory"},{"type":"module","title":"Time - TelemetryMetricsPrometheus.Core","doc":"Report durations as `:second`. The BEAM and `:telemetry` events use `:native` time\nunits. Converting to seconds is as simple as adding the conversion tuple for\nthe unit - `{:native, :second}`\n\n#","ref":"TelemetryMetricsPrometheus.Core.html#module-time"},{"type":"module","title":"Naming - TelemetryMetricsPrometheus.Core","doc":"`Telemetry.Metrics` definition names do not translate easily to Prometheus naming\nconventions. By default, the name provided when creating your definition uses parts\nof the provided name to determine what event to listen to and which event measurement\nto use.\n\nFor example, `\"http.request.duration\"` results in listening for  `[:http, :request]`\nevents and use `:duration` from the event measurements. Prometheus would recommend\na name of `http_request_duration_seconds` as a good name.\n\nIt is therefore recommended to use the name in your definition to reflect the name\nyou wish to see reported, e.g. `http.request.duration.seconds` or `[:http, :request, :duration, :seconds]` and use the `:event_name` override and `:measurement` options in your definition.\n\nExample:\n\n    Metrics.distribution(\n      \"http.request.duration.seconds\",\n      event_name: [:http, :request, :complete],\n      measurement: :duration,\n      unit: {:native, :second},\n      reporter_options: [\n        buckets: [0.01, 0.025, 0.05, 0.1, 0.2, 0.5, 1]\n      ]\n    )\n\nThe exporter sanitizes names to Prometheus' requirements ([Metric Naming](https://prometheus.io/docs/instrumenting/writing_exporters/#naming)) and joins the event name parts with an underscore.\n\n#","ref":"TelemetryMetricsPrometheus.Core.html#module-naming"},{"type":"module","title":"Labels - TelemetryMetricsPrometheus.Core","doc":"Labels in Prometheus are referred to as `:tags` in `Telemetry.Metrics` - see the docs\nfor more information on tag usage.\n\n**Important: Each tag + value results in a separate time series. For distributions, this\nis further complicated as a time series is created for each bucket plus one for measurements\nexceeding the limit of the last bucket - `+Inf`.**\n\nIt is recommended, but not required, to abide by Prometheus' best practices regarding labels -\n[Label Best Practices](https://prometheus.io/docs/practices/naming/#labels)\n\n#","ref":"TelemetryMetricsPrometheus.Core.html#module-labels"},{"type":"module","title":"Reporter Options - TelemetryMetricsPrometheus.Core","doc":"In some cases you may want to configure the aspects of a metric definition's\nunderlying Prometheus metric, such as the bucket boundaries for a\ndistribution. This can be achieved by passing `:reporter_options` to the\nmetric definition.\n\nThe supported `:reporter_options` are:\n\n- `:buckets` - a list of bucket boundaries for distributions. This reporter\noption is mandatory for `distributions`. Example:\n\nExample:\n\n    Metrics.distribution(\n      \"http.request.duration.seconds\",\n      event_name: [:http, :request, :complete],\n      measurement: :duration,\n      unit: {:native, :second},\n      reporter_options: [\n        buckets: [0.01, 0.025, 0.05, 0.1, 0.2, 0.5, 1]\n      ]\n    )\n\n- `:prometheus_type` - the Prometheus type that should be used for a sum,\neither `:counter` or `:gauge`.  Prometheus counters are monotonic, so a gauge\nshould be used when a sum can increase and decrease. Defaults to `:counter`.\n\nExample:\n\n    Metrics.sum(\"websocket.connection.count\", reporter_options: [prometheus_type: :gauge])\n\n#","ref":"TelemetryMetricsPrometheus.Core.html#module-reporter-options"},{"type":"module","title":"Missing or Invalid Measurements and Tags - TelemetryMetricsPrometheus.Core","doc":"If a measurement value is missing or non-numeric, the error is logged at the `debug` level\nand the event is not recorded. Events with missing tags are also logged and skipped.","ref":"TelemetryMetricsPrometheus.Core.html#module-missing-or-invalid-measurements-and-tags"},{"type":"function","title":"TelemetryMetricsPrometheus.Core.child_spec/1","doc":"Reporter's child spec.\n\nThis function allows you to start the reporter under a supervisor like this:\n\nchildren = [\n  {TelemetryMetricsPrometheus.Core, options}\n]\n\nSee `start_link/1` for options.","ref":"TelemetryMetricsPrometheus.Core.html#child_spec/1"},{"type":"function","title":"TelemetryMetricsPrometheus.Core.scrape/1","doc":"Returns a metrics scrape in Prometheus exposition format for the given reporter\nname - defaults to `:prometheus_metrics`.","ref":"TelemetryMetricsPrometheus.Core.html#scrape/1"},{"type":"function","title":"TelemetryMetricsPrometheus.Core.start_link/1","doc":"Start the `TelemetryMetricsPrometheus.Core.Supervisor`\n\nAvailable options:\n* `:name` - name of the reporter instance. Defaults to `:prometheus_metrics`\n* `:metrics` - a list of metrics to track.\n* `:start_async` - used to configure how the `TelemetryMetricsPrometheus.Core.Supervisor`\n  GenServer starts. When set to false, all of the metrics defined in `:metrics` are\n  initialized in the GenServer's `init/1` callback effectively blocking the supervision\n  tree from proceeding until all Telemetry event handlers are initialized. This is\n  useful if subsequent supervision tree children emit events on start up and you don't\n  want to miss those events due to an async start. Defaults to `true`.","ref":"TelemetryMetricsPrometheus.Core.html#start_link/1"},{"type":"type","title":"TelemetryMetricsPrometheus.Core.metrics/0","doc":"","ref":"TelemetryMetricsPrometheus.Core.html#t:metrics/0"},{"type":"type","title":"TelemetryMetricsPrometheus.Core.prometheus_option/0","doc":"","ref":"TelemetryMetricsPrometheus.Core.html#t:prometheus_option/0"},{"type":"type","title":"TelemetryMetricsPrometheus.Core.prometheus_options/0","doc":"","ref":"TelemetryMetricsPrometheus.Core.html#t:prometheus_options/0"}],"content_type":"text/markdown"}